import qiniu
import hashlib
from qiniu.services.cdn.manager import create_timestamp_anti_leech_url
from keras_preprocessing import image as imagetool
import os,io
import numpy as np

from PIL import Image
import requests 
from urllib import parse

def put_qiniu(np,
        access_key:str, 
        secret_key:str,
        domain:str,
        bucket:str):
    q = qiniu.Auth(access_key, secret_key)
    token = q.upload_token(bucket)
    img = imagetool.array_to_img(np)
    data = img.tobytes()
    key = f"{hashlib.md5(data).hexdigest()}.png"
    img.save(key)
    ret, info = qiniu.put_file(token,key,key) 
    os.remove(key)
    key = ret['key']
    base_url = f'{domain}/{key}'
    private_url = q.private_download_url(base_url, expires=3600)
    return private_url



def url_to_array(url):
    result = requests.get(url, timeout=3)
    if result.ok:
        img = Image.open(io.BytesIO(result.content))
        img =  img.convert('RGB')
        data =  np.array(img)
        return data
    else:
        print("http get:{}".format(result.status_code))
        return None

def file_to_array(path):
    f = Image.open(path)
    data = imagetool.img_to_array(f)
    return data

def url_to_file(url,filepath = None):
    d = url_to_array(url)
    if filepath is None:
        p = parse.urlparse(url)
        filepath = p.path[1:]
    i = Image.fromarray(d,"RGB")
    i.save(filepath)


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['imageworker']

package_data = \
{'': ['*']}

install_requires = \
['Pillow>=8.1.2,<9.0.0',
 'httpx>=0.17.1,<0.18.0',
 'keras_preprocessing>=1.1.2,<2.0.0',
 'numpy>=1.15.4,<2.0.0',
 'qiniu>=7.3.1,<8.0.0',
 'requests>=2.25.1,<3.0.0']

setup_kwargs = {
    'name': 'imageworker',
    'version': '0.1.10',
    'description': 'Lightweight image library',
    'long_description': '## Usage\n\n\n### file to ndarray\n\n```pycon\n>>> from imageworker import file_to_array\n>>> data = file_to_array("test.jpg")\n```\n\n### url to ndarray\n\n```pycon\n>>> from imageworker import url_to_array\n>>> data = url_to_array("https://n.sinaimg.cn/spider2021326/106/w1024h682/20210326/5927-kmvwsvy1040641.jpg")\n```\n\n### upload ndarray to qiniu cdn\n\n```pycon\n>>> key = QINIU_KEY\n>>> secret = QINIU_SECRET\n>>> domain = HOST\n>>> bucket = QINIU_BUCKET\n>>> url = put_qiniu(data,key,secret,domain,bucket) \n```\n\n\n\n',
    'author': 'kula',
    'author_email': 'kula@live.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
